@@ -3,7 +3,7 @@
 # Makeself version 2.1.x
 #  by Stephane Peter <megastep@megastep.org>
 #
-# $Id: makeself.sh,v 1.55 2005/06/02 22:35:17 megastep Exp $
+# $Id: makeself.sh,v 1.64 2008/01/04 23:52:14 megastep Exp $
 #
 # Utility to create self-extracting tar.gz archives.
 # The resulting archive is a file holding the tar.gz archive with
@@ -57,14 +57,21 @@
 #           Avoid some race conditions (Ludwig Nussel)
 #           Unset the $CDPATH variable to avoid problems if it is set. (Debian)
 #           Better handling of dot files in the archive directory.
+# - 2.1.5 : Made the md5sum detection consistent with the header code.
+#           Check for the presence of the archive directory
+#           Added --encrypt for symmetric encryption through gpg (Eric Windisch)
+#           Added support for the digest command on Solaris 10 for MD5 checksums
+#           Check for available disk space before extracting to the target directory (Andreas Schweitzer)
+#           Allow extraction to run asynchronously (patch by Peter Hatch)
+#           Use file descriptors internally to avoid error messages (patch by Kay Tiong Khoo)
 #
-# (C) 1998-2005 by Stphane Peter <megastep@megastep.org>
+# (C) 1998-2008 by Stphane Peter <megastep@megastep.org>
 #
 # This software is released under the terms of the GNU GPL version 2 and above
 # Please read the license at http://www.gnu.org/copyleft/gpl.html
 #
 
-MS_VERSION=2.1.4
+MS_VERSION=2.1.5
 MS_COMMAND="$0"
 unset CDPATH
 
@@ -143,6 +150,10 @@ do
 	COMPRESS=Unix
 	shift
 	;;
+    --encrypt)
+	COMPRESS=gpg
+	shift
+	;;
     --nocomp)
 	COMPRESS=none
 	shift
@@ -204,7 +215,16 @@ do
     esac
 done
 
-archdir="$1"
+if test $# -lt 1; then
+	MS_Usage
+else
+	if test -d "$1"; then
+		archdir="$1"
+	else
+		echo "Directory $1 does not exist."
+		exit 1
+	fi
+fi
 archname="$2"
 
 if test "$APPEND" = y; then
@@ -258,6 +278,10 @@ bzip2)
     GZIP_CMD="bzip2 -9"
     GUNZIP_CMD="bzip2 -d"
     ;;
+gpg)
+    GZIP_CMD="gpg -ac -z9"
+    GUNZIP_CMD="gpg -d"
+    ;;
 Unix)
     GZIP_CMD="compress -cf"
     GUNZIP_CMD="exec 2>&-; uncompress -c || test \\\$? -eq 2 || gzip -cd"
@@ -308,8 +332,9 @@ fi
 test -d "$archdir" || { echo "Error: $archdir does not exist."; rm -f "$tmpfile"; exit 1; }
 echo About to compress $USIZE KB of data...
 echo Adding files to archive named \"$archname\"...
-(cd "$archdir" && ( tar $TAR_ARGS - . | eval "$GZIP_CMD" ) >> "$tmpfile") || { echo Aborting: Archive directory not found or temporary file: "$tmpfile" could not be created.; rm -f "$tmpfile"; exit 1; }
-echo >> "$tmpfile" >&- # try to close the archive
+exec 3<> "$tmpfile"
+(cd "$archdir" && ( tar $TAR_ARGS - . | eval "$GZIP_CMD" >&3 ) ) || { echo Aborting: Archive directory not found or temporary file: "$tmpfile" could not be created.; exec 3>&-; rm -f "$tmpfile"; exit 1; }
+exec 3>&- # try to close the archive
 
 fsize=`cat "$tmpfile" | wc -c | tr -d " "`
 
@@ -325,21 +350,25 @@ else
 	echo "CRC: $crcsum"
 fi
 
-# Try to locate a MD5 binary
-OLD_PATH=$PATH
-PATH=${GUESS_MD5_PATH:-"$OLD_PATH:/bin:/usr/bin:/sbin:/usr/local/ssl/bin:/usr/local/bin:/opt/openssl/bin"}
-MD5_PATH=`type -p md5sum`
-MD5_PATH=${MD5_PATH:-`type -p md5`}
-PATH=$OLD_PATH
-
 if test "$NOMD5" = y; then
 	echo "skipping md5sum at user request"
 else
+	# Try to locate a MD5 binary
+	OLD_PATH=$PATH
+	PATH=${GUESS_MD5_PATH:-"$OLD_PATH:/bin:/usr/bin:/sbin:/usr/local/ssl/bin:/usr/local/bin:/opt/openssl/bin"}
+	MD5_ARG=""
+	MD5_PATH=`exec <&- 2>&-; which md5sum || type md5sum`
+	test -x $MD5_PATH || MD5_PATH=`exec <&- 2>&-; which md5 || type md5`
+	test -x $MD5_PATH || MD5_PATH=`exec <&- 2>&-; which digest || type digest`
+	PATH=$OLD_PATH
+	if test `basename $MD5_PATH` = digest; then
+		MD5_ARG="-a md5"
+	fi
 	if test -x "$MD5_PATH"; then
-		md5sum=`cat "$tmpfile" | "$MD5_PATH" | cut -b-32`;
+		md5sum=`cat "$tmpfile" | eval "$MD5_PATH $MD5_ARG" | cut -b-32`;
 		echo "MD5: $md5sum"
 	else
-		echo "MD5: none, md5sum binary not found"
+		echo "MD5: none, MD5 command not found"
 	fi
 fi
 
